@@ -14,10 +14,12 @@
 
 #include "qtermparam.h"
 
+#include <QtCore/QTranslator>
 #include <QtCore/QMutex>
 #include <QtCore/QString>
 #include <QtCore/QMap>
 #include <QtCore/QObject>
+#include <QtXml/QDomDocument>
 
 namespace QTerm
 {
@@ -31,7 +33,7 @@ class Global : public QObject
     Q_OBJECT
 public:
     enum Language {
-        SimpilifiedChinese,
+        SimplifiedChinese,
         TraditionalChinese,
         English
     };
@@ -48,9 +50,17 @@ public:
         Simplified_To_Traditional,
         Traditional_To_Simplified
     };
+
+    enum Position {
+        Hide = 0, 
+        Left, 
+        Right
+    };
+
     struct Pref {
         Conversion XIM;
         int  nWordWrap;
+        int  nCursorSize;
         bool bWheel;
         bool bWarn;
         bool bBlinkTab;
@@ -69,49 +79,56 @@ public:
     };
     static Global * instance();
     Config * fileCfg();
-    Config * addrCfg();
+    QDomDocument addrXml();
     const QString & pathLib();
     const QString & pathPic();
     const QString & pathCfg();
     void clearDir(const QString & path);
-    QStringList loadNameList();
-    bool loadAddress(int n, Param & param);
-    void saveAddress(int n, const Param & param);
-    void removeAddress(int n);
+    // XML address book
+    QMap<QString,QString> loadFavoriteList(QDomDocument);
+    bool loadAddress(QDomDocument doc, QString uuid, Param & param);
+    void saveAddress(QDomDocument doc, QString uuid, const Param & param);
+    void removeAddress(QDomDocument doc, QString uuid);
+    void saveAddressXml(const QDomDocument& doc);
+    bool convertAddressBook2XML();
+    // deprecated cfg address book, here only for conversion reason
+    bool loadAddress(Config &addrCfg, int n, Param & param);
+
     QString getOpenFileName(const QString & filter, QWidget * widget);
     QString getSaveFileName(const QString & filename, QWidget * widget);
     bool isOK();
     Pref m_pref;
     void loadPrefence();
-    enum Position {Hide, Left, Right};
     bool isBossColor() const;
     const QString & escapeString() const;
     Conversion clipConversion() const;
     Language language() const;
-    bool showStatusBar() const;
     Position scrollPosition() const;
     bool isFullScreen() const;
     bool showSwitchBar() const;
-    bool showToolBar(const QString & toolbar);
+    bool showStatusBar() const;
+    bool showMenuBar() const;
+
     const QString & style() const;
 
     void setClipConversion(Conversion conversionId);
     void setEscapeString(const QString & escapeString);
     void setScrollPosition(Position position);
     void setStatusBar(bool isShow); //Better name?
+    void setMenuBar(bool isShow);
     void setBossColor(bool isBossColor);
     void setFullScreen(bool isFullscreen);
     void setSwitchBar(bool isShow);
     void setLanguage(const Language language);
     void setStyle(const QString & style);
-    void setShowToolBar(const QString & toolbar, bool isShown);
-    void saveShowToolBar();
     void loadConfig(); //TODO: Merge with iniSettings
     void saveConfig();
-    QByteArray loadGeometry();
-    QByteArray loadState();
-    void saveGeometry( const QByteArray geometry);
-    void saveState( const QByteArray state);
+    QByteArray loadGeometry(const QString & window);
+    QByteArray loadState(const QString & window);
+    void saveGeometry(const QString & window, const QByteArray & geometry);
+    void saveState(const QString & window, const QByteArray & state);
+    void saveSession(const QList<QVariant>& sites);
+    QList<QVariant> loadSession();
     void cleanup();
     void openUrl(const QString & url);
     QString convert(const QString & source, Conversion flag);
@@ -126,11 +143,11 @@ private:
     void closeNotification(uint id);
     QString m_fileCfg;
     QString m_addrCfg;
+    QString m_addrXml;
     QString m_pathLib;
     QString m_pathPic;
     QString m_pathCfg;
     Config * m_config;
-    Config * m_address;
     QByteArray * m_windowState;
     Status m_status;
     QString m_style;
@@ -142,8 +159,10 @@ private:
     Position m_scrollPos;
     bool m_fullScreen;
     bool m_switchBar;
+    bool m_menuBar;
     Language m_language;
-    QMap<QString, bool> m_showToolBar;
+    QTranslator *m_translatorQT;
+    QTranslator *m_translatorQTerm;
 #ifdef KWALLET_ENABLED
     Wallet * m_wallet;
 #endif // KWALLET_ENABLED
